@@ -352,12 +352,21 @@ class CloudPods:
 
         # 解析返回结果，提取服务器ID
         server_ids: List[str] = []
-        if "server" in create_result and "id" in create_result["server"]:
+        if not create_result or not isinstance(create_result, dict):
+            log.warning(f"创建服务器失败，返回结果: {create_result}")
+            return server_ids
+        if "server" in create_result.keys() and "id" in create_result["server"]:
             # 单服务器创建成功
             server_ids.append(create_result["server"]["id"])
-        elif "servers" in create_result:
+        elif "servers" in create_result.keys():
             # 多服务器创建成功
             for server_info in create_result["servers"]:
+                if "body" not in server_info.keys():
+                    log.warning(f"未获取到body，返回结果: {server_info}")
+                    continue
+                if "id" not in server_info["body"].keys():
+                    log.warning(f"未获取到server_id，返回结果: {server_info}")
+                    continue
                 server_ids.append(server_info["body"]["id"])
         else:
             # 未找到服务器ID，记录警告
@@ -695,7 +704,7 @@ if __name__ == '__main__':
     # for elem in rs:
     #     if elem["id"]=="5d6dfb67-db25-43d2-8057-116769fb3abf":
     #         print(elem)
-    rs = cloudpods.get_can_deploy_server_host_num("x86_64","uefi")
+    rs = cloudpods.get_can_deploy_server_host_num("aarch64","uefi")
     print(rs)
     # print(len(rs))
     # print(rs[0])
